Musikhaus Dreiklang - Gitarre & mehr
Description: Ihr Musikgeschäft in Lörrach - Haagen +++ Verkauf, Reparatur und Vermietung von: Gitarren & Ukulelen, Keyboards & E-Pianos, Noten & Zubehör
Keywords: Musikhaus,Lörrach,Gitarre,Ukulele,Taylor,Fender,Lakewood,E-Piano

# Musik Dreiklang

Suche:

Willkommen bei Musik Dreiklang, das Fachgeschäft für Musiker in Lörrach

- Mein Benutzerkonto
- Anmelden

## Santa Cruz Taylor Lakewood Furch Stanford Fender Yamaha
Gitarrenreparatur - Gitarre defekt? Unsere Werkstatt hilft schnell und professionell

## Musik Dreiklang - Gitarre & Mehr - Ihr Musikgeschäft in Lörrach bei Basel
Sie erreichen uns in 15min ab Schopfheim, Weil, Rheinfelden, Basel
Ausreichend Parkplätze direkt vor unserem Musikhaus!
Gitarre, Ukulele, E-Piano, Cajon, Geige, Querflöte ....
Wir sind Ihr professioneller Ansprechpartner in Sachen Musikinstrumente im Dreiländereck.

##

### Empfehlungen des Monats

Lakewood M-32 CP Akustikgitarre 2.695,00 € Barpreis inkl 19%Mwst | Yamaha CLP 535 WH Clavinova 1.679,00 € Barpreis inkl 19%Mwst | Taylor 326e Baritone LTD Sondermodell 1.949,00 € Barpreis inkl 19%Mwst
Schlagwerk CP 4017 cajon black eyes 249,00 € Barpreis inkl 19%Mwst | Schlagwerk Cajon CP 404 2in1 169,00 € Barpreis inkl 19%Mwst | Lakewood A-14 CP Akustikgitarre 1.995,00 € Barpreis inkl 19%Mwst
Taylor 614CE Natural Westerngitarre 3.199,00 € Barpreis inkl 19%Mwst | Yamaha P-255 B Stagepiano 1.399,00 € Barpreis inkl 19%Mwst | Yamaha YDP-S52 WH Digitalpiano 999,00 € Barpreis inkl 19%Mwst
Yamaha P-115B Stage Piano Black 649,00 € Barpreis inkl 19%Mwst | Taylor 914ce Westerngitarre 4.999,00 € Barpreis inkl 19%Mwst | Yamaha YDP-S52 B Digitalpiano 999,00 € Barpreis inkl 19%Mwst
YAMAHA QUERFLÖTE YFL 271 669,00 € Barpreis inkl 19%Mwst | Taylor 614CE 2015 Westerngitarre 3.599,00 € Barpreis inkl 19%Mwst | SONOR Cajon Latino 299,00 € Barpreis inkl 19%Mwst
YAMAHA P-45 B Stagepiano 449,00 € Barpreis inkl 19%Mwst | Fender American Special Tele MN OW 1.055,00 € Barpreis inkl 19%Mwst | Santa Cruz Tony Rice Akustikgitarre 5.634,00 € Barpreis inkl 19%Mwst
Schlagwerk Cajon CBA1 Bausatz 46,00 € Barpreis inkl 19%Mwst | Taylor K26 CE Koa Gitarre 4.899,00 € Barpreis inkl 19%Mwst | YAMAHA PSR-E433 Digital Keyboard 319,00 € Barpreis inkl 19%Mwst
Fender Clapton Strat BLK 2.049,00 € Barpreis inkl 19%Mwst | SONOR Cajon Listado CAJS L 289,00 € Barpreis inkl 19%Mwst | Taylor 322CE SEB Limited Edition 2.129,00 € Barpreis inkl 19%Mwst
Fender American Standard Stratocaster MN OWT E-Gitarre 1.506,00 € Barpreis inkl 19%Mwst